@@ -18,9 +18,12 @@ export LANG=C.UTF-8
 # Avoid systemd trying to color the terminal on systemd-nspawn
 export SYSTEMD_TINT_BACKGROUND=no
 
+# Avoid diffoscope looking at remote debug info through readelf
+unset DEBUGINFOD_URLS
+
 # Set buildtool properties
 export BUILDTOOL=devtools
-export BUILDTOOLVER=1:1.3.2-1-any
+export BUILDTOOLVER=1:1.4.0-1-any
 
 # Set common properties
 export PACMAN_KEYRING_DIR=/etc/pacman.d/gnupg
